@@ -92,8 +92,9 @@ anjuta_profile_error_get_type (void)
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { ANJUTA_PROFILE_ERROR_URI_READ_FAILED, "ANJUTA_PROFILE_ERROR_URI_READ_FAILED", "read-failed" },
-      { ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED, "ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED", "write-failed" },
+      { ANJUTA_PROFILE_ERROR_URI_READ_FAILED, "ANJUTA_PROFILE_ERROR_URI_READ_FAILED", "uri-read-failed" },
+      { ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED, "ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED", "uri-write-failed" },
+      { ANJUTA_PROFILE_ERROR_PLUGIN_MISSING, "ANJUTA_PROFILE_ERROR_PLUGIN_MISSING", "plugin-missing" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static (g_intern_static_string ("AnjutaProfileError"), values);
