@@ -25,10 +25,11 @@
  * @stability: Unstable
  * @include: libanjuta/anjuta-profile-manager.h
  * 
- * Anjuta uses up to two profiles. A "no project" profile is used when no
- * project is loaded a project profile when one is loaded.
+ * Anjuta uses up to three profiles. A system profile which contains mandatory
+ * plugins which are never unloaded. A user profile is used when no project is
+ * loaded and a project profile when one is loaded.
  * If a second project is loaded, it is loaded in another instance of Anjuta.
- * When a project is closed, Anjuta goes back to the "no project" profile.
+ * When a project is closed, Anjuta goes back to the user profile.
  *
  * The profile manager can be in a frozen state where you can push or 
  * pop a profile from the stack without triggering a change of the profile.
@@ -51,8 +52,6 @@ enum
 {
 	PROFILE_PUSHED,
 	PROFILE_POPPED,
-	PROFILE_DESCOPED,
-	PROFILE_SCOPED,
 	LAST_SIGNAL
 };
 
@@ -71,45 +70,6 @@ struct _AnjutaProfileManagerPriv
 static GObjectClass* parent_class = NULL;
 static guint profile_manager_signals[LAST_SIGNAL] = { 0 };
 
-static void
-on_plugin_activated (AnjutaPluginManager *plugin_manager,
-					 AnjutaPluginDescription *plugin_desc,
-					 GObject *plugin_object,
-					 AnjutaProfileManager *profile_manager)
-{
-	AnjutaProfileManagerPriv *priv;
-	priv = profile_manager->priv;
-
-	if (priv->profiles)
-	{
-		/* Add it current profile */
-		gboolean exclude;
-
-		if (!anjuta_plugin_description_get_boolean (plugin_desc, "Anjuta Plugin", "ExcludeFromSession", &exclude) || !exclude)
-		{
-			anjuta_profile_add_plugin (ANJUTA_PROFILE (priv->profiles->data),
-									   plugin_desc);
-		}
-	}
-}
-
-static void
-on_plugin_deactivated (AnjutaPluginManager *plugin_manager,
-					   AnjutaPluginDescription *plugin_desc,
-					   GObject *plugin_object,
-					   AnjutaProfileManager *profile_manager)
-{
-	AnjutaProfileManagerPriv *priv;
-	priv = profile_manager->priv;
-	
-	if (priv->profiles)
-	{
-		/* Remove from current profile */
-		anjuta_profile_remove_plugin (ANJUTA_PROFILE (priv->profiles->data),
-									  plugin_desc);
-	}
-}
-
 static void
 anjuta_profile_manager_init (AnjutaProfileManager *object)
 {
@@ -144,10 +104,6 @@ anjuta_profile_manager_set_property (GObject *object, guint prop_id,
 	case PROP_PLUGIN_MANAGER:
 		g_return_if_fail (ANJUTA_IS_PLUGIN_MANAGER (g_value_get_object (value)));
 		priv->plugin_manager = g_value_get_object (value);
-		g_signal_connect (priv->plugin_manager, "plugin-activated",
-						  G_CALLBACK (on_plugin_activated), object);
-		g_signal_connect (priv->plugin_manager, "plugin-deactivated",
-						  G_CALLBACK (on_plugin_deactivated), object);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -236,41 +192,6 @@ anjuta_profile_manager_class_init (AnjutaProfileManagerClass *klass)
 		              G_TYPE_NONE, 1,
 		              ANJUTA_TYPE_PROFILE);
 	
-	/**
-	 * AnjutaProfileManager::profile-descoped:
-	 * @profile_manager: a #AnjutaProfileManager object.
-	 * @profile: the old unloaded #AnjutaProfile.
-	 * 
-	 * Emitted when a profile will be unloaded.
-	 */
-	profile_manager_signals[PROFILE_DESCOPED] =
-		g_signal_new ("profile-descoped",
-		              G_OBJECT_CLASS_TYPE (klass),
-		              G_SIGNAL_RUN_FIRST,
-		              G_STRUCT_OFFSET (AnjutaProfileManagerClass,
-									   profile_descoped),
-		              NULL, NULL,
-					  anjuta_cclosure_marshal_VOID__OBJECT,
-		              G_TYPE_NONE, 1,
-		              ANJUTA_TYPE_PROFILE);
-	
-	/**
-	 * AnjutaProfileManager::profile-scoped:
-	 * @profile_manager: a #AnjutaProfileManager object.
-	 * @profile: the current loaded #AnjutaProfile.
-	 * 
-	 * Emitted when a new profile is loaded.
-	 */
-	profile_manager_signals[PROFILE_SCOPED] =
-		g_signal_new ("profile-scoped",
-		              G_OBJECT_CLASS_TYPE (klass),
-		              G_SIGNAL_RUN_FIRST,
-		              G_STRUCT_OFFSET (AnjutaProfileManagerClass,
-									   profile_scoped),
-		              NULL, NULL,
-					  anjuta_cclosure_marshal_VOID__OBJECT,
-		              G_TYPE_NONE, 1,
-		              ANJUTA_TYPE_PROFILE);
 }
 
 GType
@@ -320,133 +241,35 @@ anjuta_profile_manager_new (AnjutaPluginManager *plugin_manager)
 }
 
 static gboolean
-anjuta_profile_manager_load_profile (AnjutaProfileManager *profile_manager,
-									 AnjutaProfile *profile,
-									 AnjutaProfile *previous_profile,
-									 GError **error)
+anjuta_profile_manager_load_profiles (AnjutaProfileManager *profile_manager, GError **error)
 {
 	AnjutaProfileManagerPriv *priv;
-	GList *active_plugins, *node;
-	GList *plugins_to_activate, *plugins_to_deactivate;
-	GList *selected_plugins;
-		
-	GHashTable *active_plugins_hash, *plugins_to_activate_hash;
-	
+	gboolean loaded = FALSE;
+
 	priv = profile_manager->priv;
-	
-	/* Disable profile synchronization while the profile is being activated */
-	g_signal_handlers_block_by_func (priv->plugin_manager,
-									 G_CALLBACK (on_plugin_activated),
-									 profile_manager);
-	g_signal_handlers_block_by_func (priv->plugin_manager,
-									 G_CALLBACK (on_plugin_deactivated),
-									 profile_manager);
-	
-	/* Emit pre-change for the last profile */
-	if (previous_profile)
-	{
-		g_signal_emit_by_name (profile_manager, "profile-descoped",
-							   previous_profile);
-	}
-	
-	/* Prepare plugins to activate */
-	plugins_to_activate_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
-	
-	/* Select plugins in the profile */
-	if (profile)
-		selected_plugins = anjuta_profile_get_plugins (profile);
-	else
-		selected_plugins = NULL;
-	
-	node = selected_plugins;
-	while (node)
-	{
-		g_hash_table_insert (plugins_to_activate_hash, node->data, node->data);
-		node = g_list_next (node);
-	}
-	
-	/* Prepare active plugins hash */
-	active_plugins =
-		anjuta_plugin_manager_get_active_plugins (priv->plugin_manager);
-	active_plugins_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
-	node = active_plugins;
-	while (node)
-	{
-		g_hash_table_insert (active_plugins_hash, node->data, node->data);
-		node = g_list_next (node);
-	}
-	
-	plugins_to_deactivate = NULL;
-	
-	/* Prepare plugins to deactiveate that are already active, but are
-	 * not requested to be active
-	 */
-	node = active_plugins;
-	while (node)
-	{
-		if (!g_hash_table_lookup (plugins_to_activate_hash, node->data))
-		{
-			plugins_to_deactivate = g_list_prepend (plugins_to_deactivate,
-													node->data);
-		}
-		node = g_list_next (node);
-	}
-	plugins_to_deactivate = g_list_reverse (plugins_to_deactivate);
 
-	/* Deactivate plugins */
-	node = plugins_to_deactivate;
-	while (node)
+	/* If there is no freeze load profile now */
+	while ((priv->freeze_count <= 0) && (priv->profiles_queue != NULL))
 	{
-		AnjutaPluginDescription *desc;
-		gchar *plugin_id = NULL;
-		
-		desc = (AnjutaPluginDescription *)node->data;
-		anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-											  "Location", &plugin_id);
-		g_assert (plugin_id != NULL);
-		
-		/* DEBUG_PRINT ("Profile: deactivating %s", plugin_id); */
-		
-		anjuta_plugin_manager_unload_plugin_by_id (priv->plugin_manager,
-		                                           plugin_id);
-		node = g_list_next (node);
-	}
-	
-	/* Prepare the plugins to activate */
-	plugins_to_activate = NULL;
-	node = selected_plugins;
-	while (node)
-	{
-		if (!g_hash_table_lookup (active_plugins_hash, node->data))
-			plugins_to_activate = g_list_prepend (plugins_to_activate,
-												   node->data);
-		node = g_list_next (node);
-	}
-	
-	/* Now activate the plugins */
-	if (plugins_to_activate)
-	{
-		/* Activate them */
-		plugins_to_activate = g_list_reverse (plugins_to_activate);
-		anjuta_plugin_manager_activate_plugins (priv->plugin_manager,
-												plugins_to_activate);
-	}
-	
-	g_list_free (plugins_to_activate);
-	g_list_free (active_plugins);
-	
-	g_hash_table_destroy (plugins_to_activate_hash);
-	g_hash_table_destroy (active_plugins_hash);
+		AnjutaProfile *previous_profile = NULL;
+		GList *node;
 
-	/* Enable profile synchronization */
-	g_signal_handlers_unblock_by_func (priv->plugin_manager,
-									   G_CALLBACK (on_plugin_activated),
-									   profile_manager);
-	g_signal_handlers_unblock_by_func (priv->plugin_manager,
-									   G_CALLBACK (on_plugin_deactivated),
-									   profile_manager);
-	g_signal_emit_by_name (profile_manager, "profile-scoped", profile);
-	return TRUE;
+		/* We need to load each profile one by one because a "system" profile
+		 * contains plugins which are never unloaded. */
+		if (priv->profiles)
+			previous_profile = priv->profiles->data;
+		node = g_list_last (priv->profiles_queue);
+		priv->profiles_queue = g_list_remove_link (priv->profiles_queue, node);
+		priv->profiles = g_list_concat (node, priv->profiles);
+
+		/* Load profile. Note that loading a profile can trigger the load of
+		 * additional profile. Typically loading the default profile will
+		 * trigger the load of the last project profile. */
+		if (previous_profile != NULL) anjuta_profile_unload (previous_profile, NULL);
+		loaded = anjuta_profile_load (ANJUTA_PROFILE (node->data), error);
+	}
+
+	return loaded;
 }
 
 static gboolean
@@ -457,29 +280,11 @@ anjuta_profile_manager_queue_profile (AnjutaProfileManager *profile_manager,
 	AnjutaProfileManagerPriv *priv;
 	
 	priv = profile_manager->priv;
-	priv->profiles_queue = g_list_prepend (priv->profiles_queue,
-											profile);
+
+	priv->profiles_queue = g_list_prepend (priv->profiles_queue, profile);
+
 	/* If there is no freeze load profile now */
-	if (priv->freeze_count <= 0)
-	{
-		AnjutaProfile *previous_profile = NULL;
-		
-		if (priv->profiles)
-			previous_profile = priv->profiles->data;
-		
-		/* Push queued profiles in stack */
-		priv->profiles = g_list_concat (priv->profiles_queue, priv->profiles);
-		priv->profiles_queue = NULL;
-		
-		return anjuta_profile_manager_load_profile (profile_manager,
-										ANJUTA_PROFILE (priv->profiles->data),
-													previous_profile,
-													error);
-	}
-	else
-	{
-		return FALSE;
-	}
+	return anjuta_profile_manager_load_profiles (profile_manager, error);
 }
 
 /**
@@ -511,7 +316,7 @@ anjuta_profile_manager_push (AnjutaProfileManager *profile_manager,
 /**
  * anjuta_profile_manager_pop:
  * @profile_manager: the #AnjutaProfileManager object.
- * @profile_name: the name of the profile to remove.
+ * @profile: the #AnjutaProfile to remove.
  * @error: error propagation and reporting.
  * 
  * Remove a profile from the profile manager stack. If the manager is not
@@ -524,10 +329,9 @@ anjuta_profile_manager_push (AnjutaProfileManager *profile_manager,
  */
 gboolean
 anjuta_profile_manager_pop (AnjutaProfileManager *profile_manager,
-							const gchar *profile_name, GError **error)
+							AnjutaProfile *profile, GError **error)
 {
 	AnjutaProfileManagerPriv *priv;
-	AnjutaProfile *profile;
 
 	g_return_val_if_fail (ANJUTA_IS_PROFILE_MANAGER (profile_manager), FALSE);
 	priv = profile_manager->priv;
@@ -535,9 +339,7 @@ anjuta_profile_manager_pop (AnjutaProfileManager *profile_manager,
 	/* First check in the queue */
 	if (priv->profiles_queue)
 	{
-		profile = priv->profiles_queue->data;
-		g_return_val_if_fail (strcmp (anjuta_profile_get_name (profile),
-									  profile_name) == 0, FALSE);
+		g_return_val_if_fail (priv->profiles_queue->data == profile, FALSE);
 		priv->profiles_queue = g_list_remove (priv->profiles_queue, profile);
 		
 		g_signal_emit_by_name (profile_manager, "profile-popped",
@@ -550,29 +352,20 @@ anjuta_profile_manager_pop (AnjutaProfileManager *profile_manager,
 	/* Then check in the current stack */
 	if (priv->profiles)
 	{
-		profile = priv->profiles->data;
-		g_return_val_if_fail (strcmp (anjuta_profile_get_name (profile),
-									  profile_name) == 0, FALSE);
+		g_return_val_if_fail (priv->profiles->data == profile, FALSE);
 		priv->profiles = g_list_remove (priv->profiles, profile);
 		
 		g_signal_emit_by_name (profile_manager, "profile-popped",
 							   profile);
 		
 		/* Restore the next profile in the stack */
+		anjuta_profile_unload (profile, NULL);
+		g_object_unref (profile);
 		if (priv->profiles)
 		{
-			return anjuta_profile_manager_load_profile (profile_manager,
-									ANJUTA_PROFILE (priv->profiles->data),
-														profile,
-														error);
+			return anjuta_profile_load (ANJUTA_PROFILE (priv->profiles->data), error);
 		}
-		else
-		{
-			return anjuta_profile_manager_load_profile (profile_manager,
-														NULL, profile,
-														error);
-		}
-		g_object_unref (profile);
+		return TRUE;
 	}
 
 	return FALSE;
@@ -619,28 +412,8 @@ anjuta_profile_manager_thaw (AnjutaProfileManager *profile_manager,
 
 	if (priv->freeze_count > 0)
 		priv->freeze_count--;
-	
-	if (priv->freeze_count <= 0 && priv->profiles_queue)
-	{
-		AnjutaProfile *previous_profile = NULL;
-		
-		if (priv->profiles)
-			previous_profile = priv->profiles->data;
-		
-		/* Push queued profiles in stack */
-		priv->profiles = g_list_concat (priv->profiles_queue, priv->profiles);
-		priv->profiles_queue = NULL;
-		
-		/* Load the profile */
-		return anjuta_profile_manager_load_profile (profile_manager,
-										ANJUTA_PROFILE (priv->profiles->data),
-													previous_profile,
-													error);
-	}
-	else
-	{
-		return FALSE;
-	}
+
+	return anjuta_profile_manager_load_profiles (profile_manager, error);
 }
 
 /**
@@ -669,7 +442,7 @@ anjuta_profile_manager_get_current (AnjutaProfileManager *profile_manager)
  * anjuta_profile_manager_close:
  * @profile_manager: A #AnjutaProfileManager object.
  *
- * Close the #AnjutaProfileManager causing "profile-descoped" to be emitted and
+ * Close the #AnjutaProfileManager causing "descoped" to be emitted and
  * all queued and previous profiles to be released. This function is to be used
  * when destroying an Anjuta instance.
  */
@@ -682,19 +455,13 @@ anjuta_profile_manager_close (AnjutaProfileManager *profile_manager)
 
 	priv = profile_manager->priv;
 
-	g_signal_handlers_disconnect_by_func (priv->plugin_manager,
-	                                      on_plugin_activated, profile_manager);
-	g_signal_handlers_disconnect_by_func (priv->plugin_manager,
-	                                      on_plugin_deactivated, profile_manager);
-
 	if (priv->profiles)
 	{
 		AnjutaProfile *profile = ANJUTA_PROFILE (priv->profiles->data);
 
-		/* Emit "profile-descoped" so that other parts of anjuta can store
+		/* Emit "descoped" so that other parts of anjuta can store
 		 * information about the currently loaded profile. */
-		g_signal_emit_by_name (profile_manager, "profile-descoped",
-		                       profile);
+		anjuta_profile_unload (profile, NULL);
 
 		g_list_free_full (priv->profiles, g_object_unref);
 		priv->profiles = NULL;
