@@ -104,7 +104,15 @@ extern void libanjuta_iface_cclosure_marshal_VOID__STRING_STRING_STRING (GClosur
                                                                          gpointer      invocation_hint,
                                                                          gpointer      marshal_data);
 
-/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:17) */
+/* VOID:STRING,STRING,STRING,STRING,BOOLEAN,BOOLEAN,STRING (./libanjuta-iface-marshallers.list:17) */
+extern void libanjuta_iface_cclosure_marshal_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING (GClosure     *closure,
+                                                                                                       GValue       *return_value,
+                                                                                                       guint         n_param_values,
+                                                                                                       const GValue *param_values,
+                                                                                                       gpointer      invocation_hint,
+                                                                                                       gpointer      marshal_data);
+
+/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:18) */
 extern void libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -112,7 +120,7 @@ extern void libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:18) */
+/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:19) */
 extern void libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
                                                                       GValue       *return_value,
                                                                       guint         n_param_values,
@@ -120,7 +128,7 @@ extern void libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure
                                                                       gpointer      invocation_hint,
                                                                       gpointer      marshal_data);
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:19) */
+/* VOID:VOID (./libanjuta-iface-marshallers.list:20) */
 #define libanjuta_iface_cclosure_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
 G_END_DECLS
