@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 2.6.4.  */
 
 /* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +30,15 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_AMP_AC_YY_AC_PARSER_H_INCLUDED
+# define YY_AMP_AC_YY_AC_PARSER_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int amp_ac_yydebug;
+#endif
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -179,7 +188,6 @@
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef int YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
@@ -187,8 +195,6 @@ typedef int YYSTYPE;
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
-
-
 #if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
 typedef struct YYLTYPE
 {
@@ -203,14 +209,15 @@ typedef struct YYLTYPE
 #endif
 
 
-
-#ifndef YYPUSH_DECLS
-#  define YYPUSH_DECLS
-struct amp_ac_yypstate;
-typedef struct amp_ac_yypstate amp_ac_yypstate;
+#ifndef YYPUSH_MORE_DEFINED
+# define YYPUSH_MORE_DEFINED
 enum { YYPUSH_MORE = 4 };
+#endif
+
+typedef struct amp_ac_yypstate amp_ac_yypstate;
+
 #if defined __STDC__ || defined __cplusplus
-int amp_ac_yypush_parse (amp_ac_yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, AmpAcScanner* scanner);
+int amp_ac_yypush_parse (amp_ac_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE const *pushed_loc, AmpAcScanner* scanner);
 #else
 int amp_ac_yypush_parse ();
 #endif
@@ -221,9 +228,9 @@ amp_ac_yypstate * amp_ac_yypstate_new (void);
 amp_ac_yypstate * amp_ac_yypstate_new ();
 #endif
 #if defined __STDC__ || defined __cplusplus
-void amp_ac_yypstate_delete (amp_ac_yypstate *yyps);
+void amp_ac_yypstate_delete (amp_ac_yypstate *ps);
 #else
 void amp_ac_yypstate_delete ();
 #endif
-#endif
 
+#endif /* !YY_AMP_AC_YY_AC_PARSER_H_INCLUDED  */
