@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 2.6.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5"
+#define YYBISON_VERSION "2.6.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,8 +58,6 @@
 /* Pull parsers.  */
 #define YYPULL 0
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 /* Substitute the variable and function names.  */
 #define yypush_parse    amp_am_yypush_parse
@@ -75,8 +73,7 @@
 #define yylloc          amp_am_yylloc
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 358 of yacc.c  */
 #line 19 "am-parser.y"
 
 
@@ -90,8 +87,7 @@
 /* Token location is found directly from token value, there is no need to
  * maintain a separate location variable */
 #define YYLLOC_DEFAULT(Current, Rhs, N)	((Current) = YYRHSLOC(Rhs, (N) ? 1 : 0))
-
-/* Line 268 of yacc.c  */
+/* Line 358 of yacc.c  */
 #line 115 "am-parser.y"
 
 
@@ -146,14 +142,16 @@ amp_am_automake_variable (AnjutaToken *token)
 }
 
 
+/* Line 358 of yacc.c  */
+#line 147 "am-parser.c"
 
-/* Line 268 of yacc.c  */
-#line 152 "am-parser.c"
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+# ifndef YY_NULL
+#  if defined __cplusplus && 201103L <= __cplusplus
+#   define YY_NULL nullptr
+#  else
+#   define YY_NULL 0
+#  endif
+# endif
 
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
@@ -163,11 +161,17 @@ amp_am_automake_variable (AnjutaToken *token)
 # define YYERROR_VERBOSE 0
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "am-parser.h".  */
+#ifndef YY_AMP_AM_YY_AM_PARSER_H_INCLUDED
+# define YY_AMP_AM_YY_AM_PARSER_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int amp_am_yydebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -295,7 +299,6 @@ amp_am_automake_variable (AnjutaToken *token)
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef int YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
@@ -316,36 +319,37 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
-#ifndef YYPUSH_DECLS
-#  define YYPUSH_DECLS
-struct yypstate;
-typedef struct yypstate yypstate;
+
+#ifndef YYPUSH_MORE_DEFINED
+# define YYPUSH_MORE_DEFINED
 enum { YYPUSH_MORE = 4 };
+#endif
+
+typedef struct amp_am_yypstate amp_am_yypstate;
 
 #if defined __STDC__ || defined __cplusplus
-int yypush_parse (yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, AmpAmScanner* scanner);
+int amp_am_yypush_parse (amp_am_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE const *pushed_loc, AmpAmScanner* scanner);
 #else
-int yypush_parse ();
+int amp_am_yypush_parse ();
 #endif
 
 #if defined __STDC__ || defined __cplusplus
-yypstate * yypstate_new (void);
+amp_am_yypstate * amp_am_yypstate_new (void);
 #else
-yypstate * yypstate_new ();
+amp_am_yypstate * amp_am_yypstate_new ();
 #endif
 #if defined __STDC__ || defined __cplusplus
-void yypstate_delete (yypstate *yyps);
+void amp_am_yypstate_delete (amp_am_yypstate *ps);
 #else
-void yypstate_delete ();
-#endif
+void amp_am_yypstate_delete ();
 #endif
 
+#endif /* !YY_AMP_AM_YY_AM_PARSER_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 343 of yacc.c  */
-#line 349 "am-parser.c"
+/* Line 377 of yacc.c  */
+#line 353 "am-parser.c"
 
 #ifdef short
 # undef short
@@ -398,24 +402,24 @@ typedef short int yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -520,20 +524,20 @@ union yyalloc
 #endif
 
 #if defined YYCOPY_NEEDED && YYCOPY_NEEDED
-/* Copy COUNT objects from FROM to TO.  The source and destination do
+/* Copy COUNT objects from SRC to DST.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
 #  if defined __GNUC__ && 1 < __GNUC__
-#   define YYCOPY(To, From, Count) \
-      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
+#   define YYCOPY(Dst, Src, Count) \
+      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
 #  else
-#   define YYCOPY(To, From, Count)		\
-      do					\
-	{					\
-	  YYSIZE_T yyi;				\
-	  for (yyi = 0; yyi < (Count); yyi++)	\
-	    (To)[yyi] = (From)[yyi];		\
-	}					\
+#   define YYCOPY(Dst, Src, Count)              \
+      do                                        \
+        {                                       \
+          YYSIZE_T yyi;                         \
+          for (yyi = 0; yyi < (Count); yyi++)   \
+            (Dst)[yyi] = (Src)[yyi];            \
+        }                                       \
       while (YYID (0))
 #  endif
 # endif
@@ -684,7 +688,7 @@ static const yytype_uint16 yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -710,7 +714,7 @@ static const char *const yytname[] =
   "prerequisite_token", "command_token", "value_token", "head_token",
   "space_token", "comment_token", "equal_token", "rule_token",
   "depend_token", "name_token", "variable_token", "automake_token",
-  "include_token", 0
+  "include_token", YY_NULL
 };
 #endif
 
@@ -918,10 +922,10 @@ static const yytype_int16 yytable[] =
       80,   -12,   -12,     0,     3,     4,     0,   -12
 };
 
-#define yypact_value_is_default(yystate) \
-  ((yystate) == (-134))
+#define yypact_value_is_default(Yystate) \
+  (!!((Yystate) == (-134)))
 
-#define yytable_value_is_error(yytable_value) \
+#define yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const yytype_int16 yycheck[] =
@@ -1050,17 +1054,18 @@ static const yytype_uint8 yystos[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)					\
-do								\
-  if (yychar == YYEMPTY && yylen == 1)				\
-    {								\
-      yychar = (Token);						\
-      yylval = (Value);						\
-      YYPOPSTACK (1);						\
-      goto yybackup;						\
-    }								\
-  else								\
-    {								\
+#define YYBACKUP(Token, Value)                                  \
+do                                                              \
+  if (yychar == YYEMPTY)                                        \
+    {                                                           \
+      yychar = (Token);                                         \
+      yylval = (Value);                                         \
+      YYPOPSTACK (yylen);                                       \
+      yystate = *yyssp;                                         \
+      goto yybackup;                                            \
+    }                                                           \
+  else                                                          \
+    {                                                           \
       yyerror (&yylloc, scanner, YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
@@ -1070,32 +1075,33 @@ while (YYID (0))
 #define YYTERROR	1
 #define YYERRCODE	256
 
-
 /* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -1166,6 +1172,8 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp, scanner)
     AmpAmScanner* scanner;
 #endif
 {
+  FILE *yyo = yyoutput;
+  YYUSE (yyo);
   if (!yyvaluep)
     return;
   YYUSE (yylocationp);
@@ -1425,12 +1433,12 @@ static int
 yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yytype_int16 *yyssp, int yytoken)
 {
-  YYSIZE_T yysize0 = yytnamerr (0, yytname[yytoken]);
+  YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
   YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
-  const char *yyformat = 0;
+  const char *yyformat = YY_NULL;
   /* Arguments of yyformat. */
   char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
   /* Number of reported tokens (one for the "unexpected", one per
@@ -1490,7 +1498,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (0, yytname[yyx]);
+                yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
                 if (! (yysize <= yysize1
                        && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                   return 2;
@@ -1586,6 +1594,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, scanner)
 }
 
 
+
 struct yypstate
   {
     /* Number of syntax errors so far.  */
@@ -1600,7 +1609,7 @@ struct yypstate
        `yyvs': related to semantic values.
        `yyls': related to locations.
 
-       Refer to the stacks thru separate pointers, to allow yyoverflow
+       Refer to the stacks through separate pointers, to allow yyoverflow
        to reallocate them elsewhere.  */
 
     /* The state stack.  */
@@ -1641,7 +1650,7 @@ yypstate_new ()
   yypstate *yyps;
   yyps = (yypstate *) malloc (sizeof *yyps);
   if (!yyps)
-    return 0;
+    return YY_NULL;
   yyps->yynew = 1;
   return yyps;
 }
@@ -1702,6 +1711,28 @@ yypush_parse (yyps, yypushed_char, yypushed_val, yypushed_loc, scanner)
 /* The lookahead symbol.  */
 int yychar;
 
+
+#if defined __GNUC__ && (4 < __GNUC__ + (6 <= __GNUC_MINOR__))
+/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
+    _Pragma ("GCC diagnostic push") \
+    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
+    _Pragma ("GCC diagnostic pop")
+#else
+/* Default value used for initialization, for pacifying older GCCs
+   or non-GCC compilers.  */
+static YYSTYPE yyval_default;
+# define YYLVAL_INITIALIZE() (yylval = yyval_default)
+#endif
+#ifndef YYLVAL_INITIALIZE
+# define YYLVAL_INITIALIZE()
+#endif
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+
 /* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
@@ -1711,7 +1742,7 @@ YYLTYPE yylloc;
   int yyn;
   int yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int yytoken;
+  int yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE yyval;
@@ -1736,7 +1767,6 @@ YYLTYPE yylloc;
       goto yyread_pushed_token;
     }
 
-  yytoken = 0;
   yyss = yyssa;
   yyvs = yyvsa;
   yyls = yylsa;
@@ -1757,12 +1787,12 @@ YYLTYPE yylloc;
   yyvsp = yyvs;
   yylsp = yyls;
 
+  YYLVAL_INITIALIZE ();
 #if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
   /* Initialize the default location before parsing starts.  */
   yylloc.first_line   = yylloc.last_line   = 1;
   yylloc.first_column = yylloc.last_column = 1;
 #endif
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1920,7 +1950,9 @@ yyread_pushed_token:
   yychar = YYEMPTY;
 
   yystate = yyn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++yylsp = yylloc;
   goto yynewstate;
 
@@ -1958,8 +1990,7 @@ yyreduce:
   switch (yyn)
     {
         case 11:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 188 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (amp_am_automake_variable ((yyvsp[(2) - (5)])), NULL);
@@ -1973,8 +2004,7 @@ yyreduce:
     break;
 
   case 12:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 198 "am-parser.y"
     {
 		AnjutaToken *list;
@@ -1988,8 +2018,7 @@ yyreduce:
     break;
 
   case 13:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 210 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
@@ -2000,8 +2029,7 @@ yyreduce:
     break;
 
   case 14:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 218 "am-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
@@ -2014,8 +2042,7 @@ yyreduce:
     break;
 
   case 15:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 226 "am-parser.y"
     {
 		AnjutaToken *list;
@@ -2031,8 +2058,7 @@ yyreduce:
     break;
 
   case 24:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 263 "am-parser.y"
     {
 		anjuta_token_set_type ((yyvsp[(1) - (1)]), ANJUTA_TOKEN_EOL);
@@ -2041,8 +2067,7 @@ yyreduce:
     break;
 
   case 25:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 267 "am-parser.y"
     {
 		(yyval) = NULL;
@@ -2050,8 +2075,7 @@ yyreduce:
     break;
 
   case 26:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 270 "am-parser.y"
     {
 		anjuta_token_set_type ((yyvsp[(1) - (1)]), ANJUTA_TOKEN_COMMENT);
@@ -2060,8 +2084,7 @@ yyreduce:
     break;
 
   case 32:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 293 "am-parser.y"
     {
 		(yyval) = anjuta_token_merge_previous ((yyvsp[(2) - (3)]), (yyvsp[(1) - (3)]));
@@ -2070,8 +2093,7 @@ yyreduce:
     break;
 
   case 33:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 300 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2080,8 +2102,7 @@ yyreduce:
     break;
 
   case 34:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 304 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (3)]), (yyvsp[(2) - (3)]));
@@ -2090,8 +2111,7 @@ yyreduce:
     break;
 
   case 35:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 308 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (3)]), (yyvsp[(2) - (3)]));
@@ -2100,8 +2120,7 @@ yyreduce:
     break;
 
   case 36:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 315 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
@@ -2111,8 +2130,7 @@ yyreduce:
     break;
 
   case 37:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 320 "am-parser.y"
     {
 		if ((yyvsp[(1) - (3)]) != NULL) anjuta_token_set_type ((yyvsp[(1) - (3)]), ANJUTA_TOKEN_START);
@@ -2124,8 +2142,7 @@ yyreduce:
     break;
 
   case 38:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 329 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_LIST, NULL);
@@ -2134,8 +2151,7 @@ yyreduce:
     break;
 
   case 39:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 333 "am-parser.y"
     {
 		anjuta_token_set_type ((yyvsp[(2) - (3)]), ANJUTA_TOKEN_NEXT);
@@ -2145,8 +2161,7 @@ yyreduce:
     break;
 
   case 42:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 351 "am-parser.y"
     {
 		(yyval) = NULL;
@@ -2154,8 +2169,7 @@ yyreduce:
     break;
 
   case 44:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 358 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_SPACE, NULL);
@@ -2164,8 +2178,7 @@ yyreduce:
     break;
 
   case 45:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 366 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2173,8 +2186,7 @@ yyreduce:
     break;
 
   case 46:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 375 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2183,8 +2195,7 @@ yyreduce:
     break;
 
   case 47:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 379 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2193,8 +2204,7 @@ yyreduce:
     break;
 
   case 48:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 383 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2203,8 +2213,7 @@ yyreduce:
     break;
 
   case 49:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 387 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2212,8 +2221,7 @@ yyreduce:
     break;
 
   case 50:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 390 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2221,8 +2229,7 @@ yyreduce:
     break;
 
   case 51:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 393 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2230,8 +2237,7 @@ yyreduce:
     break;
 
   case 52:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 396 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2239,8 +2245,7 @@ yyreduce:
     break;
 
   case 53:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 399 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2248,8 +2253,7 @@ yyreduce:
     break;
 
   case 54:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 405 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2258,8 +2262,7 @@ yyreduce:
     break;
 
   case 55:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 409 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2268,8 +2271,7 @@ yyreduce:
     break;
 
   case 56:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 413 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2277,8 +2279,7 @@ yyreduce:
     break;
 
   case 57:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 416 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2286,8 +2287,7 @@ yyreduce:
     break;
 
   case 58:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 419 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2295,8 +2295,7 @@ yyreduce:
     break;
 
   case 59:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 422 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2304,8 +2303,7 @@ yyreduce:
     break;
 
   case 60:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 425 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2313,8 +2311,7 @@ yyreduce:
     break;
 
   case 61:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 431 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ARGUMENT, NULL);
@@ -2323,8 +2320,7 @@ yyreduce:
     break;
 
   case 62:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 435 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ARGUMENT, NULL);
@@ -2333,8 +2329,7 @@ yyreduce:
     break;
 
   case 63:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 439 "am-parser.y"
     {
 		(yyval) = anjuta_token_new_static (ANJUTA_TOKEN_ARGUMENT, NULL);
@@ -2343,8 +2338,7 @@ yyreduce:
     break;
 
   case 64:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 443 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2352,8 +2346,7 @@ yyreduce:
     break;
 
   case 65:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 446 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2361,8 +2354,7 @@ yyreduce:
     break;
 
   case 66:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 449 "am-parser.y"
     {
 		anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2370,8 +2362,7 @@ yyreduce:
     break;
 
   case 74:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 468 "am-parser.y"
     {
 		amp_am_scanner_parse_variable (scanner, (yyval));
@@ -2379,8 +2370,7 @@ yyreduce:
     break;
 
   case 75:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 474 "am-parser.y"
     {
 		amp_am_scanner_parse_ac_variable (scanner, (yyval));
@@ -2388,9 +2378,8 @@ yyreduce:
     break;
 
 
-
-/* Line 1806 of yacc.c  */
-#line 2394 "am-parser.c"
+/* Line 1813 of yacc.c  */
+#line 2383 "am-parser.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2555,7 +2544,9 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   yyerror_range[2] = yylloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -2584,7 +2575,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#if !defined(yyoverflow) || YYERROR_VERBOSE
+#if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2629,8 +2620,6 @@ yypushreturn:
 }
 
 
-
-/* Line 2067 of yacc.c  */
+/* Line 2076 of yacc.c  */
 #line 608 "am-parser.y"
 
-
