@@ -53,8 +53,13 @@ struct _AmpTargetNode {
 	GList* tokens;
 };
 
+typedef struct _AmpTargetNodeClass AmpTargetNodeClass;
 
+struct _AmpTargetNodeClass {
+	AmpNodeClass parent_class;
+};
 
+G_DEFINE_DYNAMIC_TYPE (AmpTargetNode, amp_target_node, AMP_TYPE_NODE);
 
 
 
@@ -243,6 +248,13 @@ amp_target_node_update_node (AmpTargetNode *node, AmpTargetNode *new_node)
 	new_node->tokens = NULL;
 }
 
+/* Get install directory */
+const gchar *
+amp_target_node_get_install_directory (AmpTargetNode *node)
+{
+	return node->install;
+}
+
 /* The target has changed which could change its children */
 void
 amp_target_changed (AmpTargetNode *node)
@@ -319,7 +331,12 @@ amp_target_node_new (const gchar *name, AnjutaProjectNodeType type, const gchar
 	node = g_object_new (AMP_TYPE_TARGET_NODE, NULL);
 	amp_target_node_set_type (node, type);
 	node->base.name = g_strdup (name);
-	node->install = g_strdup (install);
+	if ((install == NULL) && ((type & ANJUTA_PROJECT_ID_MASK) == ANJUTA_PROJECT_DATA)) {
+		node->install = g_strdup (name);
+	}
+	else {
+		node->install = g_strdup (install);
+	}
 	node->flags = flags;
 
 	amp_node_property_add_mandatory (ANJUTA_PROJECT_NODE (node));
@@ -422,6 +439,17 @@ amp_target_node_update (AmpNode *node, AmpNode *new_node)
 	return TRUE;
 }
 
+static AmpNode *
+amp_target_node_copy (AmpNode *old_node)
+{
+	AmpNode *new_node;
+	
+	new_node = AMP_NODE_CLASS (amp_target_node_parent_class)->copy (old_node);
+	amp_target_node_set_type (AMP_TARGET_NODE (new_node), anjuta_project_node_get_full_type (ANJUTA_PROJECT_NODE (old_node)));
+
+	return new_node;
+}
+
 static gboolean
 amp_target_node_write (AmpNode *node, AmpNode *parent, AmpProject *project, GError **error)
 {
@@ -490,14 +518,6 @@ amp_target_node_erase (AmpNode *target, AmpNode *parent, AmpProject *project, GE
 /* GObjet implementation
  *---------------------------------------------------------------------------*/
 
-typedef struct _AmpTargetNodeClass AmpTargetNodeClass;
-
-struct _AmpTargetNodeClass {
-	AmpNodeClass parent_class;
-};
-
-G_DEFINE_DYNAMIC_TYPE (AmpTargetNode, amp_target_node, AMP_TYPE_NODE);
-
 static void
 amp_target_node_init (AmpTargetNode *node)
 {
@@ -531,6 +551,7 @@ amp_target_node_class_init (AmpTargetNodeClass *klass)
 
 	node_class = AMP_NODE_CLASS (klass);
 	node_class->update = amp_target_node_update;
+	node_class->copy = amp_target_node_copy;
 	node_class->write = amp_target_node_write;
 	node_class->erase = amp_target_node_erase;
 }
