@@ -1543,6 +1543,7 @@ on_select_configuration (GtkRadioMenuItem *item, gpointer user_data)
 		BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (user_data);
 		gchar *name;
 		GValue *value;
+		GFile *file;
 		gchar *uri;
 
 		name = g_object_get_data (G_OBJECT (item), "untranslated_name");
@@ -1552,9 +1553,11 @@ on_select_configuration (GtkRadioMenuItem *item, gpointer user_data)
 		value = g_new0 (GValue, 1);
 		g_value_init (value, G_TYPE_STRING);
 
-		uri = build_configuration_list_get_build_uri (plugin->configurations, build_configuration_list_get_selected (plugin->configurations));
+		file = build_configuration_list_get_build_file (plugin->configurations, build_configuration_list_get_selected (plugin->configurations));
+		uri = g_file_get_uri (file);
 		g_value_set_string (value, uri);
 		g_free (uri);
+		g_object_unref (file);
 
 		anjuta_shell_add_value (ANJUTA_PLUGIN (plugin)->shell, IANJUTA_BUILDER_ROOT_URI, value, NULL);
 	}
