@@ -46,7 +46,6 @@
 #include "git-stash-pane.h"
 #include "git-stash-changes-pane.h"
 #include "git-apply-stash-pane.h"
-#include "git-diff-stash-pane.h"
 #include "git-drop-stash-pane.h"
 #include "git-clear-stash-pane.h"
 #include "git-rebase-pane.h"
@@ -151,14 +150,6 @@ AnjutaCommandBarEntry status_entries[] =
 		GTK_STOCK_APPLY,
 		G_CALLBACK (on_commit_button_clicked)
 	},
-	{
-		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
-		"Diff",
-		N_("Diff uncommitted changes"),
-		N_("Show a diff of uncommitted changes in an editor"),
-		GTK_STOCK_ZOOM_100,
-		G_CALLBACK (on_diff_button_clicked)
-	},
 	{
 		ANJUTA_COMMAND_BAR_ENTRY_FRAME,
 		"NULL",
@@ -351,14 +342,6 @@ AnjutaCommandBarEntry stash_entries[] =
 		GTK_STOCK_OK,
 		G_CALLBACK (on_apply_stash_index_button_clicked)
 	},
-	{
-		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
-		"DiffStash",
-		N_("Diff selected stash"),
-		N_("Show a diff of the selected stash"),
-		GTK_STOCK_ZOOM_100,
-		G_CALLBACK (on_diff_stash_button_clicked)
-	},
 	{
 		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
 		"DropStash",
@@ -615,14 +598,6 @@ static GtkActionEntry stash_menu_entries[] =
 		NULL,
 		G_CALLBACK (on_apply_stash_index_button_clicked)
 	},
-	{
-		"GitStashDiff",
-		NULL,
-		N_("Diff"),
-		NULL,
-		NULL,
-		G_CALLBACK (on_diff_stash_button_clicked)
-	},
 	{
 		"GitStashDrop",
 		NULL,
@@ -858,7 +833,8 @@ git_activate_plugin (AnjutaPlugin *plugin)
 	anjuta_dock_set_command_bar (ANJUTA_DOCK (git_plugin->dock), 
 	                             ANJUTA_COMMAND_BAR (git_plugin->command_bar));
 
-	gtk_widget_show_all (git_plugin->box);
+	gtk_widget_show (git_plugin->box);
+	gtk_widget_show_all (scrolled_window);
 	anjuta_shell_add_widget_custom (plugin->shell, git_plugin->box, "GitDock", 
 	                     			_("Git"), "git-plugin", 
 	                                GTK_WIDGET (gtk_builder_get_object (builder, "grip_box")), 
