@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 2.6.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5"
+#define YYBISON_VERSION "2.6.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,8 +58,6 @@
 /* Pull parsers.  */
 #define YYPULL 0
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 /* Substitute the variable and function names.  */
 #define yypush_parse    mkp_yypush_parse
@@ -75,8 +73,7 @@
 #define yylloc          mkp_yylloc
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 358 of yacc.c  */
 #line 19 "mk-parser.y"
 
 
@@ -91,8 +88,7 @@
  * maintain a separate location variable */
 #define YYLLOC_DEFAULT(Current, Rhs, N)	((Current) = YYRHSLOC(Rhs, (N) ? 1 : 0))
 
-
-/* Line 268 of yacc.c  */
+/* Line 358 of yacc.c  */
 #line 89 "mk-parser.y"
 
 
@@ -176,14 +172,16 @@ mkp_special_target (AnjutaToken *list)
 }
 
 
+/* Line 358 of yacc.c  */
+#line 177 "mk-parser.c"
 
-/* Line 268 of yacc.c  */
-#line 182 "mk-parser.c"
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+# ifndef YY_NULL
+#  if defined __cplusplus && 201103L <= __cplusplus
+#   define YY_NULL nullptr
+#  else
+#   define YY_NULL 0
+#  endif
+# endif
 
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
@@ -193,11 +191,17 @@ mkp_special_target (AnjutaToken *list)
 # define YYERROR_VERBOSE 0
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "mk-parser.h".  */
+#ifndef YY_MKP_YY_MK_PARSER_H_INCLUDED
+# define YY_MKP_YY_MK_PARSER_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int mkp_yydebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -279,7 +283,6 @@ mkp_special_target (AnjutaToken *list)
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef int YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
@@ -300,36 +303,37 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
-#ifndef YYPUSH_DECLS
-#  define YYPUSH_DECLS
-struct yypstate;
-typedef struct yypstate yypstate;
+
+#ifndef YYPUSH_MORE_DEFINED
+# define YYPUSH_MORE_DEFINED
 enum { YYPUSH_MORE = 4 };
+#endif
+
+typedef struct mkp_yypstate mkp_yypstate;
 
 #if defined __STDC__ || defined __cplusplus
-int yypush_parse (yypstate *yyps, int yypushed_char, YYSTYPE const *yypushed_val, YYLTYPE const *yypushed_loc, void* scanner);
+int mkp_yypush_parse (mkp_yypstate *ps, int pushed_char, YYSTYPE const *pushed_val, YYLTYPE const *pushed_loc, void* scanner);
 #else
-int yypush_parse ();
+int mkp_yypush_parse ();
 #endif
 
 #if defined __STDC__ || defined __cplusplus
-yypstate * yypstate_new (void);
+mkp_yypstate * mkp_yypstate_new (void);
 #else
-yypstate * yypstate_new ();
+mkp_yypstate * mkp_yypstate_new ();
 #endif
 #if defined __STDC__ || defined __cplusplus
-void yypstate_delete (yypstate *yyps);
+void mkp_yypstate_delete (mkp_yypstate *ps);
 #else
-void yypstate_delete ();
-#endif
+void mkp_yypstate_delete ();
 #endif
 
+#endif /* !YY_MKP_YY_MK_PARSER_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 343 of yacc.c  */
-#line 333 "mk-parser.c"
+/* Line 377 of yacc.c  */
+#line 337 "mk-parser.c"
 
 #ifdef short
 # undef short
@@ -382,24 +386,24 @@ typedef short int yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -504,20 +508,20 @@ union yyalloc
 #endif
 
 #if defined YYCOPY_NEEDED && YYCOPY_NEEDED
-/* Copy COUNT objects from FROM to TO.  The source and destination do
+/* Copy COUNT objects from SRC to DST.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
 #  if defined __GNUC__ && 1 < __GNUC__
-#   define YYCOPY(To, From, Count) \
-      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
+#   define YYCOPY(Dst, Src, Count) \
+      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
 #  else
-#   define YYCOPY(To, From, Count)		\
-      do					\
-	{					\
-	  YYSIZE_T yyi;				\
-	  for (yyi = 0; yyi < (Count); yyi++)	\
-	    (To)[yyi] = (From)[yyi];		\
-	}					\
+#   define YYCOPY(Dst, Src, Count)              \
+      do                                        \
+        {                                       \
+          YYSIZE_T yyi;                         \
+          for (yyi = 0; yyi < (Count); yyi++)   \
+            (Dst)[yyi] = (Src)[yyi];            \
+        }                                       \
       while (YYID (0))
 #  endif
 # endif
@@ -652,7 +656,7 @@ static const yytype_uint16 yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -672,7 +676,7 @@ static const char *const yytname[] =
   "name_prerequisite", "equal_group", "not_eol_token",
   "prerequisite_token", "command_token", "value_token", "head_token",
   "variable_token", "name_token", "rule_token", "depend_token",
-  "word_token", "space_token", "equal_token", 0
+  "word_token", "space_token", "equal_token", YY_NULL
 };
 #endif
 
@@ -842,10 +846,10 @@ static const yytype_int16 yytable[] =
       37,    38,    39,    40,    41,    42,    43,    44,    45
 };
 
-#define yypact_value_is_default(yystate) \
-  ((yystate) == (-109))
+#define yypact_value_is_default(Yystate) \
+  (!!((Yystate) == (-109)))
 
-#define yytable_value_is_error(yytable_value) \
+#define yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const yytype_int16 yycheck[] =
@@ -947,17 +951,18 @@ static const yytype_uint8 yystos[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)					\
-do								\
-  if (yychar == YYEMPTY && yylen == 1)				\
-    {								\
-      yychar = (Token);						\
-      yylval = (Value);						\
-      YYPOPSTACK (1);						\
-      goto yybackup;						\
-    }								\
-  else								\
-    {								\
+#define YYBACKUP(Token, Value)                                  \
+do                                                              \
+  if (yychar == YYEMPTY)                                        \
+    {                                                           \
+      yychar = (Token);                                         \
+      yylval = (Value);                                         \
+      YYPOPSTACK (yylen);                                       \
+      yystate = *yyssp;                                         \
+      goto yybackup;                                            \
+    }                                                           \
+  else                                                          \
+    {                                                           \
       yyerror (&yylloc, scanner, YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
@@ -967,32 +972,33 @@ while (YYID (0))
 #define YYTERROR	1
 #define YYERRCODE	256
 
-
 /* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -1063,6 +1069,8 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp, scanner)
     void* scanner;
 #endif
 {
+  FILE *yyo = yyoutput;
+  YYUSE (yyo);
   if (!yyvaluep)
     return;
   YYUSE (yylocationp);
@@ -1322,12 +1330,12 @@ static int
 yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yytype_int16 *yyssp, int yytoken)
 {
-  YYSIZE_T yysize0 = yytnamerr (0, yytname[yytoken]);
+  YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
   YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
-  const char *yyformat = 0;
+  const char *yyformat = YY_NULL;
   /* Arguments of yyformat. */
   char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
   /* Number of reported tokens (one for the "unexpected", one per
@@ -1387,7 +1395,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (0, yytname[yyx]);
+                yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
                 if (! (yysize <= yysize1
                        && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                   return 2;
@@ -1483,6 +1491,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, scanner)
 }
 
 
+
 struct yypstate
   {
     /* Number of syntax errors so far.  */
@@ -1497,7 +1506,7 @@ struct yypstate
        `yyvs': related to semantic values.
        `yyls': related to locations.
 
-       Refer to the stacks thru separate pointers, to allow yyoverflow
+       Refer to the stacks through separate pointers, to allow yyoverflow
        to reallocate them elsewhere.  */
 
     /* The state stack.  */
@@ -1538,7 +1547,7 @@ yypstate_new ()
   yypstate *yyps;
   yyps = (yypstate *) malloc (sizeof *yyps);
   if (!yyps)
-    return 0;
+    return YY_NULL;
   yyps->yynew = 1;
   return yyps;
 }
@@ -1599,6 +1608,28 @@ yypush_parse (yyps, yypushed_char, yypushed_val, yypushed_loc, scanner)
 /* The lookahead symbol.  */
 int yychar;
 
+
+#if defined __GNUC__ && (4 < __GNUC__ + (6 <= __GNUC_MINOR__))
+/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
+    _Pragma ("GCC diagnostic push") \
+    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
+    _Pragma ("GCC diagnostic pop")
+#else
+/* Default value used for initialization, for pacifying older GCCs
+   or non-GCC compilers.  */
+static YYSTYPE yyval_default;
+# define YYLVAL_INITIALIZE() (yylval = yyval_default)
+#endif
+#ifndef YYLVAL_INITIALIZE
+# define YYLVAL_INITIALIZE()
+#endif
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+
 /* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
@@ -1608,7 +1639,7 @@ YYLTYPE yylloc;
   int yyn;
   int yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int yytoken;
+  int yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE yyval;
@@ -1633,7 +1664,6 @@ YYLTYPE yylloc;
       goto yyread_pushed_token;
     }
 
-  yytoken = 0;
   yyss = yyssa;
   yyvs = yyvsa;
   yyls = yylsa;
@@ -1654,12 +1684,12 @@ YYLTYPE yylloc;
   yyvsp = yyvs;
   yylsp = yyls;
 
+  YYLVAL_INITIALIZE ();
 #if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
   /* Initialize the default location before parsing starts.  */
   yylloc.first_line   = yylloc.last_line   = 1;
   yylloc.first_column = yylloc.last_column = 1;
 #endif
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1817,7 +1847,9 @@ yyread_pushed_token:
   yychar = YYEMPTY;
 
   yystate = yyn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++yylsp = yylloc;
   goto yynewstate;
 
@@ -1855,8 +1887,7 @@ yyreduce:
   switch (yyn)
     {
         case 8:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 184 "mk-parser.y"
     {
         anjuta_token_merge_children ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -1865,8 +1896,7 @@ yyreduce:
     break;
 
   case 9:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 191 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
@@ -1879,8 +1909,7 @@ yyreduce:
     break;
 
   case 10:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 199 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_DEFINITION, NULL);
@@ -1892,8 +1921,7 @@ yyreduce:
     break;
 
   case 11:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 209 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -1901,8 +1929,7 @@ yyreduce:
     break;
 
   case 12:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 212 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (4)]), (yyvsp[(2) - (4)]));
@@ -1912,8 +1939,7 @@ yyreduce:
     break;
 
   case 13:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 220 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_RULE, NULL);
@@ -1936,8 +1962,7 @@ yyreduce:
     break;
 
   case 14:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 241 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_COMMANDS, NULL);
@@ -1945,8 +1970,7 @@ yyreduce:
     break;
 
   case 15:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 244 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (4)]), (yyvsp[(2) - (4)]));
@@ -1956,8 +1980,7 @@ yyreduce:
     break;
 
   case 19:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 262 "mk-parser.y"
     {
         (yyval) = NULL;
@@ -1965,8 +1988,7 @@ yyreduce:
     break;
 
   case 20:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 265 "mk-parser.y"
     {
         (yyval) = NULL;
@@ -1974,8 +1996,7 @@ yyreduce:
     break;
 
   case 24:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 280 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
@@ -1983,8 +2004,7 @@ yyreduce:
     break;
 
   case 25:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 283 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
@@ -1992,8 +2012,7 @@ yyreduce:
     break;
 
   case 26:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 286 "mk-parser.y"
     {
         if ((yyvsp[(1) - (3)])) anjuta_token_set_type ((yyvsp[(1) - (3)]), ANJUTA_TOKEN_START);
@@ -2005,8 +2024,7 @@ yyreduce:
     break;
 
   case 27:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 296 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_PREREQUISITE, NULL);
@@ -2015,8 +2033,7 @@ yyreduce:
     break;
 
   case 28:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 300 "mk-parser.y"
     {
         anjuta_token_set_type ((yyvsp[(2) - (3)]), ANJUTA_TOKEN_NEXT);
@@ -2026,8 +2043,7 @@ yyreduce:
     break;
 
   case 29:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 308 "mk-parser.y"
     {
         (yyval) = anjuta_token_merge_previous ((yyvsp[(2) - (3)]), (yyvsp[(1) - (3)]));
@@ -2036,8 +2052,7 @@ yyreduce:
     break;
 
   case 30:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 315 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2046,8 +2061,7 @@ yyreduce:
     break;
 
   case 31:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 319 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (3)]), (yyvsp[(2) - (3)]));
@@ -2056,8 +2070,7 @@ yyreduce:
     break;
 
   case 32:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 326 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_COMMAND, NULL);
@@ -2065,8 +2078,7 @@ yyreduce:
     break;
 
   case 33:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 329 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2074,8 +2086,7 @@ yyreduce:
     break;
 
   case 34:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 338 "mk-parser.y"
     {
 		(yyval) = NULL;
@@ -2083,8 +2094,7 @@ yyreduce:
     break;
 
   case 36:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 345 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_SPACE, NULL);
@@ -2093,8 +2103,7 @@ yyreduce:
     break;
 
   case 37:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 349 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2102,8 +2111,7 @@ yyreduce:
     break;
 
   case 39:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 356 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_NAME, NULL);
@@ -2112,8 +2120,7 @@ yyreduce:
     break;
 
   case 40:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 360 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2121,8 +2128,7 @@ yyreduce:
     break;
 
   case 42:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 367 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_VALUE, NULL);
@@ -2131,8 +2137,7 @@ yyreduce:
     break;
 
   case 43:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 371 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (ANJUTA_TOKEN_VALUE, NULL);
@@ -2141,8 +2146,7 @@ yyreduce:
     break;
 
   case 44:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 375 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2150,8 +2154,7 @@ yyreduce:
     break;
 
   case 45:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 378 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2159,8 +2162,7 @@ yyreduce:
     break;
 
   case 47:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 388 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (mkp_special_prerequisite ((yyvsp[(1) - (1)])), NULL);
@@ -2169,8 +2171,7 @@ yyreduce:
     break;
 
   case 48:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 392 "mk-parser.y"
     {
         anjuta_token_merge ((yyvsp[(1) - (2)]), (yyvsp[(2) - (2)]));
@@ -2178,8 +2179,7 @@ yyreduce:
     break;
 
   case 50:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 399 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_EQUAL, NULL);
@@ -2188,8 +2188,7 @@ yyreduce:
     break;
 
   case 51:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 403 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_IMMEDIATE_EQUAL, NULL);
@@ -2198,8 +2197,7 @@ yyreduce:
     break;
 
   case 52:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 407 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_CONDITIONAL_EQUAL, NULL);
@@ -2208,8 +2206,7 @@ yyreduce:
     break;
 
   case 53:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 411 "mk-parser.y"
     {
         (yyval) = anjuta_token_new_static (MK_TOKEN_APPEND, NULL);
@@ -2218,8 +2215,7 @@ yyreduce:
     break;
 
   case 72:
-
-/* Line 1806 of yacc.c  */
+/* Line 1813 of yacc.c  */
 #line 455 "mk-parser.y"
     {
         mkp_scanner_parse_variable (scanner, (yyval));
@@ -2227,9 +2223,8 @@ yyreduce:
     break;
 
 
-
-/* Line 1806 of yacc.c  */
-#line 2233 "mk-parser.c"
+/* Line 1813 of yacc.c  */
+#line 2228 "mk-parser.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2394,7 +2389,9 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   yyerror_range[2] = yylloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -2423,7 +2420,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#if !defined(yyoverflow) || YYERROR_VERBOSE
+#if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2468,8 +2465,6 @@ yypushreturn:
 }
 
 
-
-/* Line 2067 of yacc.c  */
+/* Line 2076 of yacc.c  */
 #line 533 "mk-parser.y"
 
-
