@@ -374,10 +374,6 @@ dispose (GObject *object)
 static void
 destroy (GtkWidget *object)
 {
-	GbfProjectView *tree;
-
-	tree = GBF_PROJECT_VIEW (object);
-
 	if (GTK_WIDGET_CLASS (gbf_project_view_parent_class)->destroy)
 		(* GTK_WIDGET_CLASS (gbf_project_view_parent_class)->destroy) (object);
 }
@@ -574,13 +570,10 @@ draw (GtkWidget *widget, cairo_t *cr)
 			}
 			gtk_tree_view_get_background_area (
 				tree_view, root, gtk_tree_view_get_column (tree_view, 0), &rect);
-			gtk_paint_hline (gtk_widget_get_style (widget),
-					 cr,
-					 gtk_widget_get_state (widget),
-					 widget,
-					 "",
-					 rect.x, rect.x + rect.width,
-					 rect.y);
+			gtk_render_line (gtk_widget_get_style_context (widget),
+			                 cr,
+			                 rect.x, rect.y,
+			                 rect.x + rect.width, rect.y);
 			gtk_tree_path_free (root);
 		}
 	}
@@ -719,7 +712,7 @@ gbf_project_view_find_selected_state (GtkTreeView *view,
 	g_return_val_if_fail (view != NULL, NULL);
 	g_return_val_if_fail (GBF_IS_PROJECT_VIEW (view), NULL);
 
-	data = gbf_project_view_get_first_selected (view, NULL);
+	data = gbf_project_view_get_first_selected (GBF_PROJECT_VIEW (view), NULL);
 	if (data != NULL)
 	{
 
