@@ -1,14 +1,14 @@
 [+ autogen5 template +]
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
+[+INCLUDE (string-append "licenses/" (get "License") ".tpl") \+]
+[+INCLUDE (string-append "indent.tpl") \+]
+/* [+INVOKE EMACS-MODELINE MODE="C" \+] */
+[+INVOKE START-INDENT\+]
 /*
  * main.cc
- * Copyright (C) [+Author+] [+(shell "date +%Y")+] <[+Email+]>
+ * Copyright (C) [+(shell "date +%Y")+] [+Author+] <[+Email+]>
  * 
-[+CASE (get "License") +]
-[+ == "BSD"  +][+(bsd  (get "Name") (get "Author") " * ")+]
-[+ == "LGPL" +][+(lgpl (get "Name") (get "Author") " * ")+]
-[+ == "GPL"  +][+(gpl  (get "Name")                " * ")+]
-[+ESAC+] */
+[+INVOKE LICENSE-DESCRIPTION PFX=" * " PROGRAM=(get "Name") OWNER=(get "Author") \+]
+ */
 
 #include <gtkmm.h>
 #include <iostream>
@@ -57,3 +57,4 @@ main (int argc, char *argv[])
 	}
 	return 0;
 }
+[+INVOKE END-INDENT\+]
