@@ -1,5 +1,8 @@
 [+ autogen5 template +]
 [+INCLUDE (string-append "licenses/" (get "License") ".tpl") \+]
+[+INCLUDE (string-append "indent.tpl") \+]
+/* [+INVOKE EMACS-MODELINE MODE="C" \+] */
+[+INVOKE START-INDENT\+]
 /*
  * main.cc
  * Copyright (C) [+(shell "date +%Y")+] [+Author+] <[+Email+]>
@@ -8,23 +11,24 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 #include <wx/wx.h>
 
 class MyApp : public wxApp
 {
-  public:
-    virtual bool OnInit();
+public:
+	virtual bool OnInit();
 };
 
 IMPLEMENT_APP(MyApp)
 
 bool MyApp::OnInit()
 {
-  wxFrame *frame = new wxFrame((wxFrame *)NULL, -1, "Hello World",
-                               wxPoint(50, 50), wxSize(450, 340));
+	wxFrame *frame = new wxFrame((wxFrame *)NULL, -1, "Hello World",
+		wxPoint(50, 50), wxSize(450, 340));
 
-  frame->Show(TRUE);
-  return TRUE;
+	frame->Show(TRUE);
+	return TRUE;
 }
+[+INVOKE END-INDENT\+]
